@@ -3,5 +3,5 @@
 ## ========================
 
 seqdplot <- function(seqdata, group=NULL, title=NULL, ...) {
-	plot(seqdata, group=group, type="d", title=title, ...)
+	seqplot(seqdata, group=group, type="d", title=title, ...)
 }
